var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/bootstrap/bootstrap.ts
import { NestFactory } from "@nestjs/core";

// src/logger/logger.ts
import { log } from "@pulumi/pulumi";
import { createColors } from "colorette";
import { format } from "util";

// src/logger/logger.constants.ts
var LogLevels;
(function(LogLevels2) {
  LogLevels2["ERROR"] = "ERROR";
  LogLevels2["WARN"] = "WARN";
  LogLevels2["INFO"] = "INFO";
  LogLevels2["DEBUG"] = "DEBUG";
})(LogLevels || (LogLevels = {}));

// src/logger/logger.ts
var colors = createColors({
  useColor: true
});
var LoggerService = class {
  static {
    __name(this, "LoggerService");
  }
  context;
  color;
  constructor(context) {
    this.context = context;
    this.color = {
      [LogLevels.ERROR]: colors.red,
      [LogLevels.WARN]: colors.yellow,
      [LogLevels.INFO]: colors.green,
      [LogLevels.DEBUG]: colors.magenta
    };
  }
  async error(message, trace, context) {
    await log.error(this.printf(LogLevels.ERROR, message, context));
    if (trace) {
      await log.debug(this.printf(LogLevels.DEBUG, trace, context));
    }
  }
  async warn(message, context) {
    return log.warn(this.printf(LogLevels.WARN, message, context));
  }
  async log(message, context) {
    return log.info(this.printf(LogLevels.INFO, message, context));
  }
  async debug(message, context) {
    return log.debug(this.printf(LogLevels.DEBUG, message, context));
  }
  printf(level, message, context) {
    const prefix = `${this.color[level](`[${this.context ?? context}]`)} `;
    if (typeof message === "string") {
      return prefix + colors.yellow(message);
    }
    message[0] = prefix + message[0];
    return colors.yellow(format(...message));
  }
};

// src/bootstrap/bootstrap.ts
var Bootstrap = class {
  static {
    __name(this, "Bootstrap");
  }
  static async create(mod) {
    const app = await NestFactory.createApplicationContext(mod, {
      logger: new LoggerService(),
      abortOnError: false
    });
    return app;
  }
};

// src/config/config.interface.ts
import { Config } from "@pulumi/pulumi";

// src/config/config.module.ts
import { Global, Module } from "@nestjs/common";
function _ts_decorate(decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
}
__name(_ts_decorate, "_ts_decorate");
var ConfigModule = class {
  static {
    __name(this, "ConfigModule");
  }
};
ConfigModule = _ts_decorate([
  Global(),
  Module({
    providers: [
      {
        provide: Config,
        useFactory: /* @__PURE__ */ __name(() => new Config(), "useFactory")
      }
    ],
    exports: [
      Config
    ]
  })
], ConfigModule);

// src/entrypoint/tsconfig-paths.ts
async function entrypointWithTsConfigPaths(options) {
  options = {
    tsconfig: "../",
    ...options
  };
  const paths = await import("tsconfig-paths");
  const config = paths.loadConfig(options.tsconfig);
  if (config.resultType === "success") {
    paths.register({
      baseUrl: config.absoluteBaseUrl,
      paths: config.paths
    });
  } else {
    throw new Error("Failed to load tsconfig paths.");
  }
  return options.cb();
}
__name(entrypointWithTsConfigPaths, "entrypointWithTsConfigPaths");

// src/parser/json-parser.service.ts
import { Injectable, Logger } from "@nestjs/common";
function _ts_decorate2(decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
}
__name(_ts_decorate2, "_ts_decorate");
var JsonParser = class {
  static {
    __name(this, "JsonParser");
  }
  logger = new Logger(this.constructor.name);
  parse(data) {
    try {
      return JSON.parse(data.toString());
    } catch (e) {
      this.logger.error("Error during parsing JSON file: %s", e.message);
      throw e;
    }
  }
  stringify(data) {
    return JSON.stringify(data, null, 2);
  }
};
JsonParser = _ts_decorate2([
  Injectable()
], JsonParser);

// src/parser/parser.module.ts
import { Module as Module2 } from "@nestjs/common";

// src/parser/yaml-parser.service.ts
import { Injectable as Injectable2, Logger as Logger2 } from "@nestjs/common";
import { parse, stringify } from "yaml";
function _ts_decorate3(decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
}
__name(_ts_decorate3, "_ts_decorate");
var YamlParser = class {
  static {
    __name(this, "YamlParser");
  }
  logger = new Logger2(this.constructor.name);
  parse(data) {
    try {
      return parse(data.toString());
    } catch (e) {
      this.logger.error("Error during parsing YAML file: %s", e.message);
      throw e;
    }
  }
  stringify(data) {
    return stringify(data, {
      prettyErrors: true
    });
  }
};
YamlParser = _ts_decorate3([
  Injectable2()
], YamlParser);

// src/parser/parser.module.ts
function _ts_decorate4(decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
}
__name(_ts_decorate4, "_ts_decorate");
var ParserModule = class {
  static {
    __name(this, "ParserModule");
  }
};
ParserModule = _ts_decorate4([
  Module2({
    providers: [
      JsonParser,
      YamlParser
    ],
    exports: [
      JsonParser,
      YamlParser
    ]
  })
], ParserModule);

// src/utils/reexport.ts
import { secret, all, unsecret, isSecret } from "@pulumi/pulumi";

// src/utils/resource-name.ts
function toResourceName(name) {
  return name.replace(/[^a-zA-Z0-9]/g, "-").toLowerCase();
}
__name(toResourceName, "toResourceName");

// src/utils/splat.ts
import { format as splat } from "util";
export {
  Bootstrap,
  ConfigModule,
  Config as ConfigService,
  JsonParser,
  LoggerService,
  ParserModule,
  YamlParser,
  all,
  entrypointWithTsConfigPaths,
  isSecret,
  secret,
  splat,
  toResourceName,
  unsecret
};
//# sourceMappingURL=index.js.map